@@ -57,8 +57,15 @@ void on_command_picker_value_changed(HildonPickerButton * button, QueenBeecon *s
 void on_logger_picker_value_changed(HildonPickerButton * button, QueenBeecon *self)
 {
 	qbw_logger(QBW_LOGGER_LOG, QBW_LOGGER_V2, "(%p) %s", self, G_STRFUNC);
+	QbwLoggerVerbosity prev_verbosity = qbw_logger(QBW_LOGGER_GET_VERBOSITY, QBW_LOGGER_VNULL, NULL);
 	QbwLoggerVerbosity verbosity = hildon_picker_button_get_active (HILDON_PICKER_BUTTON (button));
-	qbw_logger(QBW_LOGGER_SET_VERBOSITY, verbosity, NULL);
+	if (verbosity == QBW_LOGGER_VMAX) {
+		qbw_logger(QBW_LOGGER_RESET_LOGFILE, QBW_LOGGER_VNULL, NULL);
+		hildon_picker_button_set_active (HILDON_PICKER_BUTTON (button), prev_verbosity);
+		hildon_banner_show_informationf (NULL, NULL, "(%p) QBW Warning! Logfile Reset & Truncated!", self);
+	} else {
+		qbw_logger(QBW_LOGGER_SET_VERBOSITY, verbosity, NULL);
+	}
 }
 
 void testDriveBt_clicked_cb(HildonButton * button, QueenBeecon *self)
@@ -628,6 +635,7 @@ gboolean queen_beecon_advanced_dialog ( QueenBeecon *self, gint cmdSel )
 	hildon_touch_selector_append_text (HILDON_TOUCH_SELECTOR (loggerSelector), "v2");
 	hildon_touch_selector_append_text (HILDON_TOUCH_SELECTOR (loggerSelector), "v3");
 	hildon_touch_selector_append_text (HILDON_TOUCH_SELECTOR (loggerSelector), "v4");
+	hildon_touch_selector_append_text (HILDON_TOUCH_SELECTOR (loggerSelector), "Reset");
 
 	GtkWidget *loggerPicker = hildon_picker_button_new (HILDON_SIZE_AUTO_WIDTH | HILDON_SIZE_FINGER_HEIGHT, HILDON_BUTTON_ARRANGEMENT_VERTICAL);
 	hildon_button_set_title (HILDON_BUTTON (loggerPicker), "Log:");
